@@ -1,7 +1,7 @@
 from copyreg import pickle
 import zipfile
 import subprocess
-from io import BytesIO
+from contextlib import contextmanager
 from packaging import version
 import os
 import pickle
@@ -20,6 +20,16 @@ class LocalMetaNotFound(Exception):
 class UpdaterError(Exception):
     pass
 
+@contextmanager
+def openhidden(*args, **kwargs):
+    os.system(f'attrib -h {args[0]}')
+    file = open(*args, **kwargs)
+    try:
+        yield file
+    finally:
+        file.close()
+        os.system(f'attrib +h {args[0]}')
+
 class Updater:
     client_url: str
     app_name: str
@@ -34,7 +44,7 @@ class Updater:
         if not os.path.exists(fname):
             raise LocalMetaNotFound(f'localmeta not found')
         else:
-            with open(fname, 'rb') as f:
+            with openhidden(fname, 'rb') as f:
                 meta = pickle.load(f)
             
         return meta
@@ -82,7 +92,7 @@ class Updater:
             
             self.run_update(remote_meta)
             
-        with open(fname, 'wb') as f:
+        with openhidden(fname, 'wb') as f:
                 pickle.dump(remote_meta, f)
     
     def run_update(self, meta, distfold = './'):
